@@ -4,8 +4,8 @@ from ..elasticsearch.commands import ElasticSearchCommand
 
 
 class LogToDo(Todo):
-    def __init__(self, response, status_code, index, doc, headers, params):
+    def __init__(self, response, status_code, index, doc, args, headers, params):
         sentry_cmd = SentryCommand(response, status_code)
-        elastic_cmd = ElasticSearchCommand(response, status_code, index, doc, headers, params)
+        elastic_cmd = ElasticSearchCommand(response, status_code, index, doc, args, headers, params)
         commands = [sentry_cmd, elastic_cmd]
         super(LogToDo, self).__init__(commands)
